Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(9)

Unified Diff: third_party/WebKit/Source/platform/graphics/GraphicsLayer.cpp

Issue 2144303002: Made layout viewport scroll updates from compositor work like ordinary layers. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@rootScrollerOnCompositor
Patch Set: Created 4 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/platform/graphics/GraphicsLayer.cpp
diff --git a/third_party/WebKit/Source/platform/graphics/GraphicsLayer.cpp b/third_party/WebKit/Source/platform/graphics/GraphicsLayer.cpp
index c70570404b9453110306eb4553db52fe0f138466..6711335fb1c19f67eab57667838023872e45d1c0 100644
--- a/third_party/WebKit/Source/platform/graphics/GraphicsLayer.cpp
+++ b/third_party/WebKit/Source/platform/graphics/GraphicsLayer.cpp
@@ -1223,16 +1223,17 @@ void GraphicsLayer::removeLinkHighlight(LinkHighlight* linkHighlight)
updateChildList();
}
-void GraphicsLayer::setScrollableArea(ScrollableArea* scrollableArea, bool isViewport)
+void GraphicsLayer::setScrollableArea(ScrollableArea* scrollableArea, bool isVisualViewport)
{
if (m_scrollableArea == scrollableArea)
return;
m_scrollableArea = scrollableArea;
- // Viewport scrolling may involve pinch zoom and gets routed through
- // WebViewImpl explicitly rather than via GraphicsLayer::didScroll.
- if (isViewport)
+ // VisualViewport scrolling may involve pinch zoom and gets routed through
+ // WebViewImpl explicitly rather than via GraphicsLayer::didScroll since it
+ // needs to be set in tandem with the page scale delta.
+ if (isVisualViewport)
m_layer->layer()->setScrollClient(0);
else
m_layer->layer()->setScrollClient(this);

Powered by Google App Engine
This is Rietveld 408576698